@@ -16,18 +16,21 @@ fn main() {
 
 #[cfg(all(not(target_os = "android"), feature = "gl"))]
 fn main() {
-    use skia_safe::gpu::gl::FramebufferInfo;
-    use skia_safe::gpu::{BackendRenderTarget, SurfaceOrigin};
-    use skia_safe::{Color, ColorType, Surface};
-    use std::convert::TryInto;
-
-    use glutin::event::{Event, KeyboardInput, VirtualKeyCode, WindowEvent};
-    use glutin::event_loop::{ControlFlow, EventLoop};
-    use glutin::window::WindowBuilder;
-    use glutin::GlProfile;
-    type WindowedContext = glutin::ContextWrapper<glutin::PossiblyCurrent, glutin::window::Window>;
     use gl::types::*;
     use gl_rs as gl;
+    use glutin::{
+        event::{Event, KeyboardInput, VirtualKeyCode, WindowEvent},
+        event_loop::{ControlFlow, EventLoop},
+        window::WindowBuilder,
+        GlProfile,
+    };
+    use skia_safe::{
+        gpu::{gl::FramebufferInfo, BackendRenderTarget, SurfaceOrigin},
+        Color, ColorType, Surface,
+    };
+    use std::convert::TryInto;
+
+    type WindowedContext = glutin::ContextWrapper<glutin::PossiblyCurrent, glutin::window::Window>;
 
     let el = EventLoop::new();
     let wb = WindowBuilder::new().with_title("rust-skia-gl-window");
@@ -36,9 +39,11 @@ fn main() {
         .with_depth_buffer(0)
         .with_stencil_buffer(8)
         .with_pixel_format(24, 8)
-        .with_double_buffer(Some(true))
         .with_gl_profile(GlProfile::Core);
 
+    #[cfg(not(feature = "wayland"))]
+    let cb = cb.with_double_buffer(Some(true));
+
     let windowed_context = cb.build_windowed(wb, &el).unwrap();
 
     let windowed_context = unsafe { windowed_context.make_current().unwrap() };
