@@ -4,8 +4,7 @@ use std::fmt;
 
 // TODO: complete wrapper
 pub type DeferredDisplayList = RCHandle<SkDeferredDisplayList>;
-unsafe impl Send for DeferredDisplayList {}
-unsafe impl Sync for DeferredDisplayList {}
+unsafe_send_sync!(DeferredDisplayList);
 
 impl fmt::Debug for DeferredDisplayList {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
